@@ -7,7 +7,7 @@ def go_to_class(node):
     node.travel_to(node.character.place['classroom'])
 
 def leave_class(node):
-    for user in node.user.values():
+    for user in node.leader.values():
         if (user.name != 'student_body'):
             node.travel_to(user.stat['room'])
             return
@@ -25,7 +25,7 @@ def sloth(character):
         braincells.pop()['slow'] += 1
 
 def learn(node):
-    for user in node.user.values():
+    for user in node.leader.values():
         if ('xp' in user.stat):
             user.stat['xp'] += 1
 
