@@ -5,7 +5,7 @@ def absent(node):
     return (node.location != node.character.place['classroom'])
 
 def be_timely(node):
-    for user in node.user.values():
+    for user in node.leader.values():
         if (user.name not in ('physical', 'student_body')):
             return ((not user.stat['lazy']) or node.engine.coin_flip())
 
